@@ -33,8 +33,12 @@ D16 = pin.D16
 D17 = pin.D17
 D18 = pin.D18
 D19 = pin.D19
+MISO_1 = pin.D19
 D20 = pin.D20
+MOSI_1 = pin.D20
 D21 = pin.D21
+SCLK_1 = pin.D21
+SCK_1 = pin.D21
 D22 = pin.D22
 D23 = pin.D23
 D24 = pin.D24
