@@ -44,24 +44,28 @@ class I2C(Lockable):
     def scan(self):
         return self._i2c.scan()
 
-    def readfrom_into(self, address, buffer, start=0, end=None):
+    def readfrom_into(self, address, buffer, *, start=0, end=None):
         if start is not 0 or end is not None:
             if end is None:
                 end = len(buffer)
             buffer = memoryview(buffer)[start:end]
         stop = True  # remove for efficiency later
-        return self._i2c.readfrom_into(address, buffer, stop)
+        return self._i2c.readfrom_into(address, buffer, stop=stop)
 
-    def writeto(self, address, buffer, start=0, end=None, stop=True):
+    def writeto(self, address, buffer, *, start=0, end=None, stop=True):
         if isinstance(buffer, str):
             buffer = bytes([ord(x) for x in buffer])
         if start is not 0 or end is not None:
             if end is None:
-                return self._i2c.writeto(address, memoryview(buffer)[start:], stop)
+                return self._i2c.writeto(address, memoryview(buffer)[start:], stop=stop)
             else:
-                return self._i2c.writeto(address, memoryview(buffer)[start:end], stop)
-        return self._i2c.writeto(address, buffer, stop)
+                return self._i2c.writeto(address, memoryview(buffer)[start:end], stop=stop)
+        return self._i2c.writeto(address, buffer, stop=stop)
 
+    def writeto_then_readfrom(self, address, buffer_out, buffer_in, *, out_start=0, out_end=None, in_start=0, in_end=None, stop=False):
+        return self._i2c.writeto_then_readfrom(address, buffer_out, buffer_in,
+                                               out_start=out_start, out_end=out_end,
+                                               in_start=in_start, in_end=in_end, stop=stop)
 
 class SPI(Lockable):
     def __init__(self, clock, MOSI=None, MISO=None):
@@ -72,7 +76,9 @@ class SPI(Lockable):
             from machine import SPI as _SPI
         from microcontroller.pin import spiPorts
         for portId, portSck, portMosi, portMiso in spiPorts:
-            if clock == portSck and MOSI == portMosi and MISO == portMiso:
+            if ((clock == portSck) and                   # Clock is required!
+                (MOSI == portMosi or MOSI == None) and   # But can do with just output
+                (MISO == portMiso or MISO == None)):      # Or just input
                 self._spi = _SPI(portId)
                 self._pins = (portSck, portMosi, portMiso)
                 break
